@@ -35,6 +35,7 @@ from .type_defs import (
     ListConnectorsResponseTypeDef,
     ListFlowsResponseTypeDef,
     ListTagsForResourceResponseTypeDef,
+    MetadataCatalogConfigTypeDef,
     RegisterConnectorResponseTypeDef,
     SourceFlowConfigTypeDef,
     StartFlowResponseTypeDef,
@@ -42,6 +43,7 @@ from .type_defs import (
     TaskTypeDef,
     TriggerConfigTypeDef,
     UpdateConnectorProfileResponseTypeDef,
+    UpdateConnectorRegistrationResponseTypeDef,
     UpdateFlowResponseTypeDef,
 )
 
@@ -137,7 +139,8 @@ class AppflowClient(BaseClient):
         tasks: Sequence[TaskTypeDef],
         description: str = ...,
         kmsArn: str = ...,
-        tags: Mapping[str, str] = ...
+        tags: Mapping[str, str] = ...,
+        metadataCatalogConfig: MetadataCatalogConfigTypeDef = ...
     ) -> CreateFlowResponseTypeDef:
         """
         Enables your application to create a new flow using Amazon AppFlow.
@@ -307,7 +310,7 @@ class AppflowClient(BaseClient):
         connectorProvisioningConfig: ConnectorProvisioningConfigTypeDef = ...
     ) -> RegisterConnectorResponseTypeDef:
         """
-        Registers a new connector with your Amazon Web Services account.
+        Registers a new custom connector with your Amazon Web Services account.
 
         [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/appflow.html#Appflow.Client.register_connector)
         [Show boto3-stubs documentation](https://youtype.github.io/boto3_stubs_docs/mypy_boto3_appflow/client/#register_connector)
@@ -342,7 +345,7 @@ class AppflowClient(BaseClient):
     ) -> Dict[str, Any]:
         """
         Unregisters the custom connector registered in your account that matches the
-        connectorLabel provided in the request.
+        connector label provided in the request.
 
         [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/appflow.html#Appflow.Client.unregister_connector)
         [Show boto3-stubs documentation](https://youtype.github.io/boto3_stubs_docs/mypy_boto3_appflow/client/#unregister_connector)
@@ -370,6 +373,20 @@ class AppflowClient(BaseClient):
         [Show boto3-stubs documentation](https://youtype.github.io/boto3_stubs_docs/mypy_boto3_appflow/client/#update_connector_profile)
         """
 
+    def update_connector_registration(
+        self,
+        *,
+        connectorLabel: str,
+        description: str = ...,
+        connectorProvisioningConfig: ConnectorProvisioningConfigTypeDef = ...
+    ) -> UpdateConnectorRegistrationResponseTypeDef:
+        """
+        Updates a custom connector that you've previously registered.
+
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/appflow.html#Appflow.Client.update_connector_registration)
+        [Show boto3-stubs documentation](https://youtype.github.io/boto3_stubs_docs/mypy_boto3_appflow/client/#update_connector_registration)
+        """
+
     def update_flow(
         self,
         *,
@@ -378,7 +395,8 @@ class AppflowClient(BaseClient):
         sourceFlowConfig: SourceFlowConfigTypeDef,
         destinationFlowConfigList: Sequence[DestinationFlowConfigTypeDef],
         tasks: Sequence[TaskTypeDef],
-        description: str = ...
+        description: str = ...,
+        metadataCatalogConfig: MetadataCatalogConfigTypeDef = ...
     ) -> UpdateFlowResponseTypeDef:
         """
         Updates an existing flow.
