@@ -23,6 +23,7 @@ __all__ = (
     "AggregationTypeType",
     "AmplitudeConnectorOperatorType",
     "AuthenticationTypeType",
+    "CatalogTypeType",
     "ConnectionModeType",
     "ConnectorProvisioningTypeType",
     "ConnectorTypeType",
@@ -40,6 +41,7 @@ __all__ = (
     "OperatorPropertiesKeysType",
     "OperatorType",
     "OperatorsType",
+    "PathPrefixType",
     "PrefixFormatType",
     "PrefixTypeType",
     "PrivateConnectionProvisioningFailureCauseType",
@@ -69,6 +71,7 @@ __all__ = (
 AggregationTypeType = Literal["None", "SingleFile"]
 AmplitudeConnectorOperatorType = Literal["BETWEEN"]
 AuthenticationTypeType = Literal["APIKEY", "BASIC", "CUSTOM", "OAUTH2"]
+CatalogTypeType = Literal["GLUE"]
 ConnectionModeType = Literal["Private", "Public"]
 ConnectorProvisioningTypeType = Literal["LAMBDA"]
 ConnectorTypeType = Literal[
@@ -182,6 +185,7 @@ OperatorPropertiesKeysType = Literal[
     "MASK_LENGTH",
     "MASK_VALUE",
     "MATH_OPERATION_FIELDS_ORDER",
+    "ORDERED_PARTITION_KEYS_LIST",
     "SOURCE_DATA_TYPE",
     "SUBFIELD_CATEGORY_MAP",
     "TRUNCATE_LENGTH",
@@ -236,6 +240,7 @@ OperatorsType = Literal[
     "VALIDATE_NON_ZERO",
     "VALIDATE_NUMERIC",
 ]
+PathPrefixType = Literal["EXECUTION_ID", "SCHEMA_VERSION"]
 PrefixFormatType = Literal["DAY", "HOUR", "MINUTE", "MONTH", "YEAR"]
 PrefixTypeType = Literal["FILENAME", "PATH", "PATH_AND_FILENAME"]
 PrivateConnectionProvisioningFailureCauseType = Literal[
@@ -374,7 +379,16 @@ SlackConnectorOperatorType = Literal[
     "VALIDATE_NUMERIC",
 ]
 TaskTypeType = Literal[
-    "Arithmetic", "Filter", "Map", "Map_all", "Mask", "Merge", "Passthrough", "Truncate", "Validate"
+    "Arithmetic",
+    "Filter",
+    "Map",
+    "Map_all",
+    "Mask",
+    "Merge",
+    "Partition",
+    "Passthrough",
+    "Truncate",
+    "Validate",
 ]
 TrendmicroConnectorOperatorType = Literal[
     "ADDITION",
@@ -475,6 +489,7 @@ ServiceName = Literal[
     "chime-sdk-media-pipelines",
     "chime-sdk-meetings",
     "chime-sdk-messaging",
+    "chime-sdk-voice",
     "cloud9",
     "cloudcontrol",
     "clouddirectory",
@@ -579,6 +594,7 @@ ServiceName = Literal[
     "iot",
     "iot-data",
     "iot-jobs-data",
+    "iot-roborunner",
     "iot1click-devices",
     "iot1click-projects",
     "iotanalytics",
@@ -682,6 +698,7 @@ ServiceName = Literal[
     "redshift-serverless",
     "rekognition",
     "resiliencehub",
+    "resource-explorer-2",
     "resource-groups",
     "resourcegroupstaggingapi",
     "robomaker",
@@ -702,6 +719,7 @@ ServiceName = Literal[
     "sagemaker-featurestore-runtime",
     "sagemaker-runtime",
     "savingsplans",
+    "scheduler",
     "schemas",
     "sdb",
     "secretsmanager",
@@ -724,6 +742,7 @@ ServiceName = Literal[
     "ssm",
     "ssm-contacts",
     "ssm-incidents",
+    "ssm-sap",
     "sso",
     "sso-admin",
     "sso-oidc",
