@@ -34,6 +34,7 @@ from .literals import (
     OperatorPropertiesKeysType,
     OperatorsType,
     OperatorType,
+    PathPrefixType,
     PrefixFormatType,
     PrefixTypeType,
     PrivateConnectionProvisioningFailureCauseType,
@@ -126,6 +127,7 @@ __all__ = (
     "DynatraceSourcePropertiesTypeDef",
     "ErrorInfoTypeDef",
     "RangeTypeDef",
+    "GlueDataCatalogConfigTypeDef",
     "GoogleAnalyticsSourcePropertiesTypeDef",
     "IncrementalPullConfigTypeDef",
     "InforNexusSourcePropertiesTypeDef",
@@ -134,6 +136,7 @@ __all__ = (
     "ListFlowsRequestRequestTypeDef",
     "ListTagsForResourceRequestRequestTypeDef",
     "MarketoSourcePropertiesTypeDef",
+    "RegistrationOutputTypeDef",
     "OAuth2CustomParameterTypeDef",
     "OAuthPropertiesTypeDef",
     "PrefixConfigTypeDef",
@@ -174,6 +177,7 @@ __all__ = (
     "StartFlowResponseTypeDef",
     "StopFlowResponseTypeDef",
     "UpdateConnectorProfileResponseTypeDef",
+    "UpdateConnectorRegistrationResponseTypeDef",
     "UpdateFlowResponseTypeDef",
     "CustomConnectorDestinationPropertiesTypeDef",
     "EventBridgeDestinationPropertiesTypeDef",
@@ -187,6 +191,8 @@ __all__ = (
     "FlowDefinitionTypeDef",
     "ExecutionResultTypeDef",
     "FieldTypeDetailsTypeDef",
+    "MetadataCatalogConfigTypeDef",
+    "MetadataCatalogDetailTypeDef",
     "OAuth2DefaultsTypeDef",
     "SAPODataConnectorProfilePropertiesTypeDef",
     "S3OutputFormatConfigTypeDef",
@@ -197,9 +203,10 @@ __all__ = (
     "CustomConnectorProfileCredentialsTypeDef",
     "SAPODataConnectorProfileCredentialsTypeDef",
     "RegisterConnectorRequestRequestTypeDef",
+    "UpdateConnectorRegistrationRequestRequestTypeDef",
     "ListFlowsResponseTypeDef",
-    "ExecutionRecordTypeDef",
     "SupportedFieldTypeDetailsTypeDef",
+    "ExecutionRecordTypeDef",
     "AuthenticationConfigTypeDef",
     "ConnectorProfilePropertiesTypeDef",
     "S3DestinationPropertiesTypeDef",
@@ -207,8 +214,8 @@ __all__ = (
     "SourceConnectorPropertiesTypeDef",
     "TriggerConfigTypeDef",
     "ConnectorProfileCredentialsTypeDef",
-    "DescribeFlowExecutionRecordsResponseTypeDef",
     "ConnectorEntityFieldTypeDef",
+    "DescribeFlowExecutionRecordsResponseTypeDef",
     "ConnectorConfigurationTypeDef",
     "ConnectorProfileTypeDef",
     "DestinationConnectorPropertiesTypeDef",
@@ -230,6 +237,7 @@ AggregationConfigTypeDef = TypedDict(
     "AggregationConfigTypeDef",
     {
         "aggregationType": AggregationTypeType,
+        "targetFileSize": int,
     },
     total=False,
 )
@@ -938,6 +946,15 @@ RangeTypeDef = TypedDict(
     total=False,
 )
 
+GlueDataCatalogConfigTypeDef = TypedDict(
+    "GlueDataCatalogConfigTypeDef",
+    {
+        "roleArn": str,
+        "databaseName": str,
+        "tablePrefix": str,
+    },
+)
+
 GoogleAnalyticsSourcePropertiesTypeDef = TypedDict(
     "GoogleAnalyticsSourcePropertiesTypeDef",
     {
@@ -1003,6 +1020,16 @@ MarketoSourcePropertiesTypeDef = TypedDict(
     },
 )
 
+RegistrationOutputTypeDef = TypedDict(
+    "RegistrationOutputTypeDef",
+    {
+        "message": str,
+        "result": str,
+        "status": ExecutionStatusType,
+    },
+    total=False,
+)
+
 OAuth2CustomParameterTypeDef = TypedDict(
     "OAuth2CustomParameterTypeDef",
     {
@@ -1031,6 +1058,7 @@ PrefixConfigTypeDef = TypedDict(
     {
         "prefixType": PrefixTypeType,
         "prefixFormat": PrefixFormatType,
+        "pathPrefixHierarchy": Sequence[PathPrefixType],
     },
     total=False,
 )
@@ -1517,6 +1545,14 @@ UpdateConnectorProfileResponseTypeDef = TypedDict(
     },
 )
 
+UpdateConnectorRegistrationResponseTypeDef = TypedDict(
+    "UpdateConnectorRegistrationResponseTypeDef",
+    {
+        "connectorArn": str,
+        "ResponseMetadata": ResponseMetadataTypeDef,
+    },
+)
+
 UpdateFlowResponseTypeDef = TypedDict(
     "UpdateFlowResponseTypeDef",
     {
@@ -1773,6 +1809,25 @@ class FieldTypeDetailsTypeDef(_RequiredFieldTypeDetailsTypeDef, _OptionalFieldTy
     pass
 
 
+MetadataCatalogConfigTypeDef = TypedDict(
+    "MetadataCatalogConfigTypeDef",
+    {
+        "glueDataCatalog": GlueDataCatalogConfigTypeDef,
+    },
+    total=False,
+)
+
+MetadataCatalogDetailTypeDef = TypedDict(
+    "MetadataCatalogDetailTypeDef",
+    {
+        "catalogType": Literal["GLUE"],
+        "tableName": str,
+        "tableRegistrationOutput": RegistrationOutputTypeDef,
+        "partitionRegistrationOutput": RegistrationOutputTypeDef,
+    },
+    total=False,
+)
+
 OAuth2DefaultsTypeDef = TypedDict(
     "OAuth2DefaultsTypeDef",
     {
@@ -1944,6 +1999,29 @@ RegisterConnectorRequestRequestTypeDef = TypedDict(
     total=False,
 )
 
+_RequiredUpdateConnectorRegistrationRequestRequestTypeDef = TypedDict(
+    "_RequiredUpdateConnectorRegistrationRequestRequestTypeDef",
+    {
+        "connectorLabel": str,
+    },
+)
+_OptionalUpdateConnectorRegistrationRequestRequestTypeDef = TypedDict(
+    "_OptionalUpdateConnectorRegistrationRequestRequestTypeDef",
+    {
+        "description": str,
+        "connectorProvisioningConfig": ConnectorProvisioningConfigTypeDef,
+    },
+    total=False,
+)
+
+
+class UpdateConnectorRegistrationRequestRequestTypeDef(
+    _RequiredUpdateConnectorRegistrationRequestRequestTypeDef,
+    _OptionalUpdateConnectorRegistrationRequestRequestTypeDef,
+):
+    pass
+
+
 ListFlowsResponseTypeDef = TypedDict(
     "ListFlowsResponseTypeDef",
     {
@@ -1953,6 +2031,13 @@ ListFlowsResponseTypeDef = TypedDict(
     },
 )
 
+SupportedFieldTypeDetailsTypeDef = TypedDict(
+    "SupportedFieldTypeDetailsTypeDef",
+    {
+        "v1": FieldTypeDetailsTypeDef,
+    },
+)
+
 ExecutionRecordTypeDef = TypedDict(
     "ExecutionRecordTypeDef",
     {
@@ -1963,17 +2048,11 @@ ExecutionRecordTypeDef = TypedDict(
         "lastUpdatedAt": datetime,
         "dataPullStartTime": datetime,
         "dataPullEndTime": datetime,
+        "metadataCatalogDetails": List[MetadataCatalogDetailTypeDef],
     },
     total=False,
 )
 
-SupportedFieldTypeDetailsTypeDef = TypedDict(
-    "SupportedFieldTypeDetailsTypeDef",
-    {
-        "v1": FieldTypeDetailsTypeDef,
-    },
-)
-
 AuthenticationConfigTypeDef = TypedDict(
     "AuthenticationConfigTypeDef",
     {
@@ -2123,15 +2202,6 @@ ConnectorProfileCredentialsTypeDef = TypedDict(
     total=False,
 )
 
-DescribeFlowExecutionRecordsResponseTypeDef = TypedDict(
-    "DescribeFlowExecutionRecordsResponseTypeDef",
-    {
-        "flowExecutions": List[ExecutionRecordTypeDef],
-        "nextToken": str,
-        "ResponseMetadata": ResponseMetadataTypeDef,
-    },
-)
-
 _RequiredConnectorEntityFieldTypeDef = TypedDict(
     "_RequiredConnectorEntityFieldTypeDef",
     {
@@ -2162,6 +2232,15 @@ class ConnectorEntityFieldTypeDef(
     pass
 
 
+DescribeFlowExecutionRecordsResponseTypeDef = TypedDict(
+    "DescribeFlowExecutionRecordsResponseTypeDef",
+    {
+        "flowExecutions": List[ExecutionRecordTypeDef],
+        "nextToken": str,
+        "ResponseMetadata": ResponseMetadataTypeDef,
+    },
+)
+
 ConnectorConfigurationTypeDef = TypedDict(
     "ConnectorConfigurationTypeDef",
     {
@@ -2371,6 +2450,7 @@ _OptionalCreateFlowRequestRequestTypeDef = TypedDict(
         "description": str,
         "kmsArn": str,
         "tags": Mapping[str, str],
+        "metadataCatalogConfig": MetadataCatalogConfigTypeDef,
     },
     total=False,
 )
@@ -2401,6 +2481,9 @@ DescribeFlowResponseTypeDef = TypedDict(
         "createdBy": str,
         "lastUpdatedBy": str,
         "tags": Dict[str, str],
+        "metadataCatalogConfig": MetadataCatalogConfigTypeDef,
+        "lastRunMetadataCatalogDetails": List[MetadataCatalogDetailTypeDef],
+        "schemaVersion": int,
         "ResponseMetadata": ResponseMetadataTypeDef,
     },
 )
@@ -2419,6 +2502,7 @@ _OptionalUpdateFlowRequestRequestTypeDef = TypedDict(
     "_OptionalUpdateFlowRequestRequestTypeDef",
     {
         "description": str,
+        "metadataCatalogConfig": MetadataCatalogConfigTypeDef,
     },
     total=False,
 )
